[dev.garbage] runtime: raise StackGuard limit for Windows (again)

640 bytes ought to be enough for anybody.

We'll bring this back down before Go 1.5. That's issue 9214.

TBR=rlh
CC=golang-codereviews
https://golang.org/cl/188730043
diff --git a/test/nosplit.go b/test/nosplit.go
index 3a63e87..799f2c5 100644
--- a/test/nosplit.go
+++ b/test/nosplit.go
@@ -268,11 +268,11 @@
 				name := m[1]
 				size, _ := strconv.Atoi(m[2])
 
 				// The limit was originally 128 but is now 384.
 				// Instead of rewriting the test cases above, adjust
 				// the first stack frame to use up the extra 32 bytes.
 				if i == 0 {
-					size += 384 - 128
+					size += 512 - 128
 				}
 
 				if size%ptrSize == 4 {
@@ -268,11 +268,11 @@
 				size, _ := strconv.Atoi(m[2])
 
-				// The limit was originally 128 but is now 384.
+				// The limit was originally 128 but is now 512.
 				// Instead of rewriting the test cases above, adjust
 				// the first stack frame to use up the extra 32 bytes.